[vlc-commits] [Git][videolan/vlc][master] 3 commits: contrib: update gpg-error to 1.57
Jean-Baptiste Kempf (@jbk)
gitlab at videolan.org
Tue Aug 4 11:59:26 UTC 2026
Jean-Baptiste Kempf pushed to branch master at VideoLAN / VLC
Commits:
19414f11 by Jean-Baptiste Kempf at 2026-08-04T12:37:28+02:00
contrib: update gpg-error to 1.57
- - - - -
a207273a by Steve Lhomme at 2026-08-04T12:37:28+02:00
contrib: gpg-error: fix UWP build
- - - - -
f05c1700 by Steve Lhomme at 2026-08-04T12:37:28+02:00
contrib: gpg-error: update to 1.61
- - - - -
15 changed files:
- contrib/src/gpg-error/0004-use-WCHAR-API-for-temporary-windows-folder.patch
- contrib/src/gpg-error/0007-don-t-use-GetThreadLocale-on-UWP.patch
- contrib/src/gpg-error/0008-don-t-use-GetUserNameW-on-Windows-10.patch
- contrib/src/gpg-error/0009-gpg-error-config.in-add-missing-GPG_ERROR_CONFIG_LIB.patch
- contrib/src/gpg-error/0011-logging-add-ws2tcpip.h-include-for-proper-inet_pton-.patch
- contrib/src/gpg-error/0012-use-GetCurrentProcessId-in-UWP.patch
- contrib/src/gpg-error/0013-configure-allow-building-Windows-with-disable-thread.patch
- contrib/src/gpg-error/0014-core-disable-locking-API-with-disable-threads.patch
- contrib/src/gpg-error/0015-core-disable-process-spawning-with-disable-threads.patch
- + contrib/src/gpg-error/0016-w32-utils-fix-init-utils-syntax.patch
- contrib/src/gpg-error/SHA512SUMS
- contrib/src/gpg-error/gpg-error-createfile2.patch
- contrib/src/gpg-error/gpg-error-uwp-GetFileSize.patch
- contrib/src/gpg-error/gpg-error-uwp-fix.patch
- contrib/src/gpg-error/rules.mak
Changes:
=====================================
contrib/src/gpg-error/0004-use-WCHAR-API-for-temporary-windows-folder.patch
=====================================
@@ -1,17 +1,17 @@
-From 1def00f0b864977a7477219c5a8277fcc0e8b9a3 Mon Sep 17 00:00:00 2001
+From 1ea7ae5d446590548a74e82c92674baf3de87c1c Mon Sep 17 00:00:00 2001
From: Steve Lhomme <robux4 at ycbcr.xyz>
Date: Thu, 23 Oct 2025 12:17:08 +0200
-Subject: [PATCH 04/14] use WCHAR API for temporary windows folder
+Subject: [PATCH 04/16] use WCHAR API for temporary windows folder
---
src/estream.c | 16 ++++++++--------
1 file changed, 8 insertions(+), 8 deletions(-)
diff --git a/src/estream.c b/src/estream.c
-index 7e1d55c..6062001 100644
+index d2cdc12..d5965e5 100644
--- a/src/estream.c
+++ b/src/estream.c
-@@ -5115,27 +5115,27 @@ tmpfd (void)
+@@ -5134,27 +5134,27 @@ tmpfd (void)
{
#ifdef HAVE_W32_SYSTEM
int attempts, n;
@@ -45,7 +45,7 @@ index 7e1d55c..6062001 100644
*p++ = '\\';
name = p;
for (attempts=0; attempts < 10; attempts++)
-@@ -5147,8 +5147,8 @@ tmpfd (void)
+@@ -5166,8 +5166,8 @@ tmpfd (void)
*p++ = tohex (((value >> 28) & 0x0f));
value <<= 4;
}
@@ -57,5 +57,5 @@ index 7e1d55c..6062001 100644
0,
NULL,
--
-2.45.1.windows.1
+2.52.0.windows.1
=====================================
contrib/src/gpg-error/0008-don-t-use-GetUserNameW-on-Windows-10.patch
=====================================
@@ -1,7 +1,7 @@
-From e2df6855f455bf3731d407e00da7d6a39827b0ea Mon Sep 17 00:00:00 2001
+From 70cc95fa9c5573f991899e96099bb288f14bbd1f Mon Sep 17 00:00:00 2001
From: Steve Lhomme <robux4 at ycbcr.xyz>
Date: Thu, 23 Oct 2025 12:19:44 +0200
-Subject: [PATCH 08/14] don't use GetUserNameW on Windows 10+
+Subject: [PATCH 08/16] don't use GetUserNameW on Windows 10+
It's not available in UWP
---
@@ -48,5 +48,5 @@ index b6d6a55..2830452 100644
#else /* !HAVE_W32_SYSTEM */
--
-2.45.1.windows.1
+2.52.0.windows.1
=====================================
contrib/src/gpg-error/0009-gpg-error-config.in-add-missing-GPG_ERROR_CONFIG_LIB.patch
=====================================
@@ -1,7 +1,7 @@
-From 8ceb454e05af8be392dc18309f1800a4945398a5 Mon Sep 17 00:00:00 2001
+From 08801e4e4cd5b5e114d60b39640c56f8249c2305 Mon Sep 17 00:00:00 2001
From: Steve Lhomme <robux4 at ycbcr.xyz>
Date: Thu, 23 Oct 2025 12:20:16 +0200
-Subject: [PATCH 09/14] gpg-error-config.in: add missing
+Subject: [PATCH 09/16] gpg-error-config.in: add missing
GPG_ERROR_CONFIG_LIBS_PRIVATE
Otherwise the confirmity check fails
@@ -23,5 +23,5 @@ index 3b45928..e50a9d2 100644
output="$output @GPG_ERROR_CONFIG_MT_LIBS@"
fi
--
-2.45.1.windows.1
+2.52.0.windows.1
=====================================
contrib/src/gpg-error/0011-logging-add-ws2tcpip.h-include-for-proper-inet_pton-.patch
=====================================
@@ -1,7 +1,7 @@
-From 349afde1939f2faaad667024428bd02cb26af86b Mon Sep 17 00:00:00 2001
+From 24d81369de61a3cf9ff2cf7f3018af398b00bc1b Mon Sep 17 00:00:00 2001
From: Steve Lhomme <robux4 at ycbcr.xyz>
Date: Thu, 23 Oct 2025 12:23:02 +0200
-Subject: [PATCH 11/14] logging: add ws2tcpip.h include for proper inet_pton
+Subject: [PATCH 11/16] logging: add ws2tcpip.h include for proper inet_pton
definition
---
@@ -21,5 +21,5 @@ index 4f52d80..5aded01 100644
#else /*!HAVE_W32_SYSTEM*/
# include <sys/socket.h>
--
-2.45.1.windows.1
+2.52.0.windows.1
=====================================
contrib/src/gpg-error/0012-use-GetCurrentProcessId-in-UWP.patch
=====================================
@@ -1,7 +1,7 @@
-From 6fbb7b9ec5d4102e1a4c2fcbdc31dd080959963d Mon Sep 17 00:00:00 2001
+From 909a8195823f15f7efec9a8a6913b1f3492ec1b4 Mon Sep 17 00:00:00 2001
From: Steve Lhomme <robux4 at ycbcr.xyz>
Date: Thu, 23 Oct 2025 12:24:20 +0200
-Subject: [PATCH 12/14] use GetCurrentProcessId() in UWP
+Subject: [PATCH 12/16] use GetCurrentProcessId() in UWP
getpid() is not declared
---
@@ -24,5 +24,5 @@ index 5aded01..2cacb45 100644
--
-2.45.1.windows.1
+2.52.0.windows.1
=====================================
contrib/src/gpg-error/0013-configure-allow-building-Windows-with-disable-thread.patch
=====================================
@@ -1,7 +1,7 @@
-From aa9ec7d915bb43cb35e685f384142eb347ccea9b Mon Sep 17 00:00:00 2001
+From 642c53393bf204c98b991fe247513212600dfb2b Mon Sep 17 00:00:00 2001
From: Steve Lhomme <robux4 at ycbcr.xyz>
Date: Fri, 24 Oct 2025 08:28:33 +0200
-Subject: [PATCH 13/14] configure: allow building Windows with
+Subject: [PATCH 13/16] configure: allow building Windows with
--disable-threads
---
@@ -9,12 +9,12 @@ Subject: [PATCH 13/14] configure: allow building Windows with
1 file changed, 3 insertions(+), 3 deletions(-)
diff --git a/configure.ac b/configure.ac
-index c327835..4ed37e1 100644
+index 1f2fe0d..c2b9a36 100644
--- a/configure.ac
+++ b/configure.ac
-@@ -154,9 +154,9 @@ esac
- AC_SUBST(EXTRA_LIBS_FOR_BUILD)
-
+@@ -142,9 +142,9 @@ case "${host}" in
+ ;;
+ esac
-if test "$have_w32_system" != yes; then
+dnl if test "$have_w32_system" != yes; then
@@ -24,7 +24,7 @@ index c327835..4ed37e1 100644
# We build libgpg-error with large file support so that we have a 64
# bit off_t. Our external interface uses the gpgrt_off_t which is
-@@ -634,7 +634,7 @@ if test "$have_w32_system" = yes; then
+@@ -624,7 +624,7 @@ if test "$have_w32_system" = yes; then
if test "$have_w64_system" = yes; then
AC_DEFINE(HAVE_W64_SYSTEM,1,[Defined if we run on 64 bit W32 API system])
fi
@@ -34,5 +34,5 @@ index c327835..4ed37e1 100644
if test x"$gl_use_threads" = xno; then
lock_obj_h_generated=yes
--
-2.45.1.windows.1
+2.52.0.windows.1
=====================================
contrib/src/gpg-error/0014-core-disable-locking-API-with-disable-threads.patch
=====================================
@@ -1,7 +1,7 @@
-From 749be993cfc7a9994f4e0733182fc6dbb88bd655 Mon Sep 17 00:00:00 2001
+From 29d71e76eed00840acbae83cd82c765876720e2b Mon Sep 17 00:00:00 2001
From: Steve Lhomme <robux4 at ycbcr.xyz>
Date: Thu, 6 Nov 2025 13:31:25 +0100
-Subject: [PATCH 14/14] core: disable locking API with --disable-threads
+Subject: [PATCH 14/16] core: disable locking API with --disable-threads
The _gpgrt_lock_t structure used in the specialized lock API's are not
matching the structure set by gen-lock-obj.sh with --disable-threads.
@@ -17,7 +17,7 @@ In particular LOCK_ABI_VERSION is not set.
6 files changed, 23 insertions(+)
diff --git a/src/gen-lock-obj.sh b/src/gen-lock-obj.sh
-index 6e78c5f..ae867ba 100755
+index a8d9352..fb906ff 100755
--- a/src/gen-lock-obj.sh
+++ b/src/gen-lock-obj.sh
@@ -59,6 +59,8 @@ typedef struct
@@ -30,7 +30,7 @@ index 6e78c5f..ae867ba 100755
else
AWK_VERSION_OUTPUT=$($AWK 'BEGIN { print PROCINFO["version"] }')
diff --git a/src/gpgrt-int.h b/src/gpgrt-int.h
-index 8d2a936..f859a5b 100644
+index b8533dc..00c0c75 100644
--- a/src/gpgrt-int.h
+++ b/src/gpgrt-int.h
@@ -137,12 +137,21 @@ void _gpgrt_post_syscall (void);
@@ -128,5 +128,5 @@ index c389635..69599f2 100644
+
+#endif /* !GPGRT_LOCK_NOT_SUPPORTED */
--
-2.45.1.windows.1
+2.52.0.windows.1
=====================================
contrib/src/gpg-error/0015-core-disable-process-spawning-with-disable-threads.patch
=====================================
@@ -1,7 +1,7 @@
-From 10922c66bd0b717114c6b3080e0737b7676afd86 Mon Sep 17 00:00:00 2001
+From 8c21110007d4d0589f2962f19b1a66aae48f1404 Mon Sep 17 00:00:00 2001
From: Steve Lhomme <robux4 at ycbcr.xyz>
Date: Thu, 6 Nov 2025 14:52:04 +0100
-Subject: [PATCH 15/15] core: disable process spawning with --disable-threads
+Subject: [PATCH 15/16] core: disable process spawning with --disable-threads
---
src/spawn-posix.c | 4 ++++
@@ -10,7 +10,7 @@ Subject: [PATCH 15/15] core: disable process spawning with --disable-threads
3 files changed, 10 insertions(+)
diff --git a/src/spawn-posix.c b/src/spawn-posix.c
-index 8cdd032..0791b8a 100644
+index 55f6379..195c2c6 100644
--- a/src/spawn-posix.c
+++ b/src/spawn-posix.c
@@ -58,6 +58,8 @@
@@ -22,14 +22,14 @@ index 8cdd032..0791b8a 100644
/* Definition for the gpgrt_spawn_actions_t. Note that there is a
* different one for Windows. */
struct gpgrt_spawn_actions {
-@@ -1066,3 +1068,5 @@ _gpgrt_process_wait_list (gpgrt_process_t *process_list, int count, int hang)
+@@ -1068,3 +1070,5 @@ _gpgrt_process_wait_list (gpgrt_process_t *process_list, int count, int hang)
return ec;
}
+
+#endif /* !GPGRT_LOCK_NOT_SUPPORTED */
diff --git a/src/spawn-w32.c b/src/spawn-w32.c
-index cb15dd0..3a3b648 100644
+index 70f5833..3f76f68 100644
--- a/src/spawn-w32.c
+++ b/src/spawn-w32.c
@@ -49,6 +49,8 @@
@@ -41,14 +41,14 @@ index cb15dd0..3a3b648 100644
/* Define to 1 do enable debugging. */
#define DEBUG_W32_SPAWN 0
-@@ -1218,3 +1220,5 @@ _gpgrt_process_wait_list (gpgrt_process_t *process_list, int count, int hang)
+@@ -1235,3 +1237,5 @@ _gpgrt_process_wait_list (gpgrt_process_t *process_list, int count, int hang)
return ec;
}
+
+#endif /* !GPGRT_LOCK_NOT_SUPPORTED */
diff --git a/src/visibility.c b/src/visibility.c
-index 54c4e2a..4a97b6d 100644
+index 5574f33..b3d810b 100644
--- a/src/visibility.c
+++ b/src/visibility.c
@@ -1133,6 +1133,7 @@ gpgrt_close_all_fds (int from, int *keep_fds)
@@ -68,5 +68,5 @@ index 54c4e2a..4a97b6d 100644
int
--
-2.45.1.windows.1
+2.52.0.windows.1
=====================================
contrib/src/gpg-error/0016-w32-utils-fix-init-utils-syntax.patch
=====================================
@@ -0,0 +1,28 @@
+From 177f99434c4501bd153059071dc03eda362f1b28 Mon Sep 17 00:00:00 2001
+From: Jean-Baptiste Kempf <jb at videolan.org>
+Date: Mon, 29 Jun 2026 11:48:00 +0200
+Subject: [PATCH 16/16] w32-utils: fix init utils syntax
+
+---
+ src/w32-utils.c | 4 ++++
+ 1 file changed, 4 insertions(+)
+
+diff --git a/src/w32-utils.c b/src/w32-utils.c
+index 5cf4fbd..afb8cca 100644
+--- a/src/w32-utils.c
++++ b/src/w32-utils.c
+@@ -68,7 +68,11 @@ w32_shgetfolderpath (HWND a, int b, HANDLE c, DWORD d)
+ {
+ void *handle;
+
++#if WINAPI_FAMILY_PARTITION (WINAPI_PARTITION_DESKTOP)
+ handle = LoadLibraryEx ("shell32.dll", NULL, 0);
++#else
++ handle = NULL;
++#endif
+ if (!handle)
+ {
+ _gpgrt_w32_set_errno (-1);
+--
+2.52.0.windows.1
+
=====================================
contrib/src/gpg-error/SHA512SUMS
=====================================
@@ -1 +1 @@
-ff4160f4133cf1a90eddf5f59d6248214b59db4f021f124302be37bf04fa1f2eb665560914cbe289095e630a31ba141252e7a72a8e6dbbc622cb135a2066259a libgpg-error-1.56.tar.bz2
+3e59eb52d061709fd8dfe56a4b36d2d5b49dd5e0c90c283899669d6a355286cb3a3f851631f8456c78c48b652bb31a4c1f8b081ccdf87e5db64b313d141a7670 libgpg-error-1.61.tar.bz2
=====================================
contrib/src/gpg-error/gpg-error-createfile2.patch
=====================================
@@ -1,7 +1,7 @@
-From 2b5fff174b5b9ebaff32e653f3accea0ac782acb Mon Sep 17 00:00:00 2001
+From 81efaac078270d106ada3dba6268f9d662af4fdd Mon Sep 17 00:00:00 2001
From: Steve Lhomme <robux4 at ycbcr.xyz>
Date: Tue, 23 May 2023 14:31:16 +0200
-Subject: [PATCH 05/14] use CreateFile2 in Win8 as CreateFileW is forbidden in
+Subject: [PATCH 05/16] use CreateFile2 in Win8 as CreateFileW is forbidden in
UWP
---
@@ -11,10 +11,10 @@ Subject: [PATCH 05/14] use CreateFile2 in Win8 as CreateFileW is forbidden in
3 files changed, 47 insertions(+)
diff --git a/src/estream.c b/src/estream.c
-index 6062001..f7ab037 100644
+index d5965e5..f148d43 100644
--- a/src/estream.c
+++ b/src/estream.c
-@@ -2058,6 +2058,17 @@ func_file_create_w32 (void **cookie, HANDLE *rethd, const char *path,
+@@ -2059,6 +2059,17 @@ func_file_create_w32 (void **cookie, HANDLE *rethd, const char *path,
else
creation_distribution |= OPEN_EXISTING;
@@ -32,7 +32,7 @@ index 6062001..f7ab037 100644
hd = CreateFileW (wpath,
desired_access,
share_mode,
-@@ -2065,6 +2076,7 @@ func_file_create_w32 (void **cookie, HANDLE *rethd, const char *path,
+@@ -2066,6 +2077,7 @@ func_file_create_w32 (void **cookie, HANDLE *rethd, const char *path,
creation_distribution,
flags_and_attrs,
NULL); /* template file */
@@ -40,7 +40,7 @@ index 6062001..f7ab037 100644
if (hd == INVALID_HANDLE_VALUE)
{
_set_errno (map_w32_to_errno (GetLastError ()));
-@@ -5148,6 +5160,17 @@ tmpfd (void)
+@@ -5167,6 +5179,17 @@ tmpfd (void)
value <<= 4;
}
wcscpy (p, L".tmp");
@@ -58,7 +58,7 @@ index 6062001..f7ab037 100644
file = CreateFileW (buffer,
GENERIC_READ | GENERIC_WRITE,
0,
-@@ -5155,6 +5178,7 @@ tmpfd (void)
+@@ -5174,6 +5197,7 @@ tmpfd (void)
CREATE_NEW,
FILE_ATTRIBUTE_TEMPORARY | FILE_FLAG_DELETE_ON_CLOSE,
NULL);
@@ -67,7 +67,7 @@ index 6062001..f7ab037 100644
{
int fd = _open_osfhandle ((intptr_t)file, 0);
diff --git a/src/spawn-w32.c b/src/spawn-w32.c
-index ecc9437..cb15dd0 100644
+index f21991a..70f5833 100644
--- a/src/spawn-w32.c
+++ b/src/spawn-w32.c
@@ -224,10 +224,23 @@ w32_open_null (int for_write, int enable_null_device)
@@ -95,10 +95,10 @@ index ecc9437..cb15dd0 100644
_gpgrt_log_debug ("can't open 'nul': ec=%d\n", (int)GetLastError ());
return hfile;
diff --git a/src/w32-gettext.c b/src/w32-gettext.c
-index 5b15a77..42aa01c 100644
+index 980d905..129b730 100644
--- a/src/w32-gettext.c
+++ b/src/w32-gettext.c
-@@ -1216,8 +1216,18 @@ load_domain (const char *filename)
+@@ -1227,8 +1227,18 @@ load_domain (const char *filename)
if (!wfilename)
fh = INVALID_HANDLE_VALUE;
else
@@ -118,5 +118,5 @@ index 5b15a77..42aa01c 100644
}
if (fh == INVALID_HANDLE_VALUE)
--
-2.45.1.windows.1
+2.52.0.windows.1
=====================================
contrib/src/gpg-error/gpg-error-uwp-GetFileSize.patch
=====================================
@@ -1,17 +1,17 @@
-From 8e1e760bef6aa94e6e71000ead2bc21716a06d19 Mon Sep 17 00:00:00 2001
+From dcb5a660eac3ba1fb5bc08ed39e176120daf781d Mon Sep 17 00:00:00 2001
From: Steve Lhomme <robux4 at ycbcr.xyz>
Date: Thu, 23 Oct 2025 12:18:54 +0200
-Subject: [PATCH 06/14] don't use GetFileSize on UWP
+Subject: [PATCH 06/16] don't use GetFileSize on UWP
---
src/w32-gettext.c | 8 ++++++++
1 file changed, 8 insertions(+)
diff --git a/src/w32-gettext.c b/src/w32-gettext.c
-index 42aa01c..bf085cd 100644
+index 129b730..59619e9 100644
--- a/src/w32-gettext.c
+++ b/src/w32-gettext.c
-@@ -1233,7 +1233,15 @@ load_domain (const char *filename)
+@@ -1244,7 +1244,15 @@ load_domain (const char *filename)
if (fh == INVALID_HANDLE_VALUE)
return NULL;
@@ -28,5 +28,5 @@ index 42aa01c..bf085cd 100644
{
CloseHandle (fh);
--
-2.45.1.windows.1
+2.52.0.windows.1
=====================================
contrib/src/gpg-error/gpg-error-uwp-fix.patch
=====================================
@@ -1,37 +1,40 @@
-From 803dc7c5daecc9044483a9b0ad848b52f95e4189 Mon Sep 17 00:00:00 2001
+From a7e0e6d5c4b405a1d9103bb255e6d5cc6a126fb5 Mon Sep 17 00:00:00 2001
From: Steve Lhomme <robux4 at ycbcr.xyz>
Date: Mon, 15 May 2023 08:20:15 +0200
-Subject: [PATCH 03/15] fix UWP build
+Subject: [PATCH 03/16] fix UWP build
---
- src/init.c | 8 +++++++-
- src/mkheader.c | 2 +-
- 2 files changed, 8 insertions(+), 2 deletions(-)
+ src/init.c | 11 ++++++++++-
+ src/mkheader.c | 2 +-
+ 2 files changed, 11 insertions(+), 2 deletions(-)
diff --git a/src/init.c b/src/init.c
-index 7f970d9..4fe6b90 100644
+index 5a218ac..12e92e6 100644
--- a/src/init.c
+++ b/src/init.c
-@@ -82,8 +82,9 @@ static void
+@@ -81,8 +81,9 @@ static void *(*custom_realloc)(void *a, size_t n);
+ static void
windows_specific_init (void)
{
++#if WINAPI_FAMILY_PARTITION (WINAPI_PARTITION_DESKTOP)
OSVERSIONINFO osvi;
- HMODULE hntdll = GetModuleHandle ("ntdll.dll");
+ HMODULE hntdll = GetModuleHandleA ("ntdll.dll");
-+#if WINAPI_FAMILY_PARTITION (WINAPI_PARTITION_DESKTOP)
memset (&osvi,0,sizeof(osvi));
osvi.dwOSVersionInfoSize = sizeof(osvi);
- GetVersionEx (&osvi);
-@@ -91,6 +92,7 @@ windows_specific_init (void)
- /* The feature of process/thread attribute is available on Vista or
- later. */
- windows_features.is_vista_or_later = (osvi.dwMajorVersion >= 6);
-+#endif
+@@ -94,6 +95,10 @@ windows_specific_init (void)
if (hntdll && GetProcAddress (hntdll, "wine_get_version"))
windows_features.semihosted_by_wine = 1;
-@@ -589,7 +591,11 @@ _gpgrt_windows_feature (int k)
++#else
++ windows_features.is_vista_or_later = 1;
++ windows_features.semihosted_by_wine = 0;
++#endif
+ }
+ #endif
+
+@@ -590,7 +595,11 @@ _gpgrt_windows_feature (int k)
switch (k)
{
case GPGRT_WINDOWS_PROC_ATTRIBUTE:
@@ -44,10 +47,10 @@ index 7f970d9..4fe6b90 100644
case GPGRT_WINDOWS_UNDER_WINE:
return windows_features.semihosted_by_wine;
diff --git a/src/mkheader.c b/src/mkheader.c
-index 7c772e6..779e0ab 100644
+index 09727d5..71432fd 100644
--- a/src/mkheader.c
+++ b/src/mkheader.c
-@@ -623,7 +623,7 @@ write_special (const char *fname, int lnr, const char *tag)
+@@ -606,7 +606,7 @@ write_special (const char *fname, int lnr, const char *tag)
}
else if (!strcmp (tag, "include:os-add"))
{
@@ -57,5 +60,5 @@ index 7c772e6..779e0ab 100644
include_file (fname, lnr, "w32-add.h", write_line);
}
--
-2.45.1.windows.1
+2.52.0.windows.1
=====================================
contrib/src/gpg-error/0007-don-t-use-GetThreadLocale-on-UWP.patch
=====================================
@@ -1,29 +1,30 @@
-From bed81fbf76b81b6468a8e04cd07155f8358773ab Mon Sep 17 00:00:00 2001
+From 93e6aee29cdefc2c8679643d4ef0b9fcae9e8deb Mon Sep 17 00:00:00 2001
From: Steve Lhomme <robux4 at ycbcr.xyz>
Date: Thu, 23 Oct 2025 12:19:07 +0200
-Subject: [PATCH 07/14] don't use GetThreadLocale on UWP
+Subject: [PATCH 07/16] don't use GetThreadLocale on UWP
---
src/w32-gettext.c | 4 ++++
1 file changed, 4 insertions(+)
diff --git a/src/w32-gettext.c b/src/w32-gettext.c
-index bf085cd..3186458 100644
+index 59619e9..dc6795b 100644
--- a/src/w32-gettext.c
+++ b/src/w32-gettext.c
-@@ -648,8 +648,12 @@ my_nl_locale_name (const char *categoryname)
+@@ -650,9 +650,13 @@ my_nl_locale_name (const char *categoryname)
if (retval != NULL && retval[0] != '\0')
return retval;
+#if !WINAPI_FAMILY_PARTITION (WINAPI_PARTITION_DESKTOP)
+ lcid = LOCALE_CUSTOM_DEFAULT;
+#else
- /* Use native Win32 API locale ID. */
- lcid = GetThreadLocale ();
+ /* Use native Win32 API language ID or use GetThreadLocale on XP */
+ lcid = get_thread_ui_language? get_thread_ui_language ()
+ : GetThreadLocale ();
+#endif
+
/* Strip off the sorting rules, keep only the language part. */
langid = LANGIDFROMLCID (lcid);
- }
--
-2.45.1.windows.1
+2.52.0.windows.1
=====================================
contrib/src/gpg-error/rules.mak
=====================================
@@ -1,5 +1,5 @@
# GPGERROR
-GPGERROR_VERSION := 1.56
+GPGERROR_VERSION := 1.61
GPGERROR_URL := $(GNUGPG)/libgpg-error/libgpg-error-$(GPGERROR_VERSION).tar.bz2
$(TARBALLS)/libgpg-error-$(GPGERROR_VERSION).tar.bz2:
@@ -33,10 +33,12 @@ libgpg-error: libgpg-error-$(GPGERROR_VERSION).tar.bz2 .sum-gpg-error
$(APPLY) $(SRC)/gpg-error/0013-configure-allow-building-Windows-with-disable-thread.patch
$(APPLY) $(SRC)/gpg-error/0014-core-disable-locking-API-with-disable-threads.patch
$(APPLY) $(SRC)/gpg-error/0015-core-disable-process-spawning-with-disable-threads.patch
+ $(APPLY) $(SRC)/gpg-error/0016-w32-utils-fix-init-utils-syntax.patch
# use the ANSI version of Environment API's as the rest of the code
sed -i.orig -e 's/ExpandEnvironmentStrings /ExpandEnvironmentStringsA /g' $(UNPACK_DIR)/src/w32-reg.c
sed -i.orig -e 's/SetEnvironmentVariable /SetEnvironmentVariableA /g' $(UNPACK_DIR)/src/sysutils.c
sed -i.orig -e 's/GetEnvironmentVariable /GetEnvironmentVariableA /g' $(UNPACK_DIR)/src/sysutils.c
+ sed -i.orig -e 's/GetModuleHandle /GetModuleHandleA /g' $(UNPACK_DIR)/src/w32-gettext.c
$(MOVE)
View it on GitLab: https://code.videolan.org/videolan/vlc/-/compare/6e3a1eb80a48a25f390d1c2d899feeac2b49fd05...f05c1700319af85ca4254618d1a5e9aabd249a80
--
View it on GitLab: https://code.videolan.org/videolan/vlc/-/compare/6e3a1eb80a48a25f390d1c2d899feeac2b49fd05...f05c1700319af85ca4254618d1a5e9aabd249a80
You're receiving this email because of your account on code.videolan.org. Manage all notifications: https://code.videolan.org/-/profile/notifications | Help: https://code.videolan.org/help
More information about the vlc-commits
mailing list